Module blaxel.core.client.models.job_execution_spec
===================================================

Classes
-------

`JobExecutionSpec(parallelism: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, tasks: blaxel.core.client.types.Unset | list['JobExecutionTask'] = <blaxel.core.client.types.Unset object>)`
:   Job execution specification
    
    Attributes:
        parallelism (Union[Unset, int]): Number of parallel tasks
        tasks (Union[Unset, list['JobExecutionTask']]): List of execution tasks
    
    Method generated by attrs for class JobExecutionSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `parallelism`
    :

    `tasks`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :